@@ -3,8 +3,8 @@ command."""
 
 from setuptools.command.install_lib import install_lib as _install_lib
 
+from ..utils import distribution_hide_listing, distutils_log, new_style
 from . import set_build_base_mixin
-from ..utils import distribution_hide_listing, new_style, distutils_log
 
 
 class install_lib(set_build_base_mixin, new_style(_install_lib)):
@@ -15,4 +15,5 @@ class install_lib(set_build_base_mixin, new_style(_install_lib)):
         with distribution_hide_listing(self.distribution):
             outfiles = super(install_lib, self).install()
         if outfiles is not None:
-            distutils_log.info("copied %d files" % len(outfiles))
+            distutils_log.info("copied %d files", len(outfiles))
+        return outfiles
